diff lisp/eshell/em-glob.el @ 111455:f21190964294

Silence compilation of some shell files. * lisp/eshell/em-unix.el (eshell-remove-entries, eshell/rm) (eshell-shuffle-files, eshell-shorthand-tar-command) (eshell-mvcpln-template, eshell/mv, eshell/cp, eshell/ln): Prefix dynamic locals `interactive', `preview', `recursive', `verbose'. * lisp/eshell/em-glob.el (eshell-extended-glob, eshell-glob-entries): Prefix dynamic local variable `matches'.
author Glenn Morris <rgm@gnu.org>
date Tue, 09 Nov 2010 19:53:03 -0800
parents f57f72bb4757
children 417b1e4d63cd
line wrap: on
line diff
--- a/lisp/eshell/em-glob.el	Tue Nov 09 19:45:29 2010 -0800
+++ b/lisp/eshell/em-glob.el	Tue Nov 09 19:53:03 2010 -0800
@@ -246,7 +246,7 @@
 
    (INCLUDE-REGEXP EXCLUDE-REGEXP (PRED-FUNC-LIST) (MOD-FUNC-LIST))"
   (let ((paths (eshell-split-path glob))
-	matches message-shown ange-cache)
+	eshell-glob-matches message-shown ange-cache)
     (unwind-protect
 	(if (and (cdr paths)
 		 (file-name-absolute-p (car paths)))
@@ -255,15 +255,15 @@
 	  (eshell-glob-entries (file-name-as-directory ".") paths))
       (if message-shown
 	  (message nil)))
-    (or (and matches (sort matches #'string<))
+    (or (and eshell-glob-matches (sort eshell-glob-matches #'string<))
 	(if eshell-error-if-no-glob
 	    (error "No matches found: %s" glob)
 	  glob))))
 
-(defvar matches)
+(defvar eshell-glob-matches)
 (defvar message-shown)
 
 ;; FIXME does this really need to abuse matches, message-shown?
 (defun eshell-glob-entries (path globs &optional recurse-p)
   "Glob the entries in PATHS, possibly recursing if RECURSE-P is non-nil."
   (let* ((entries (ignore-errors
@@ -319,7 +319,7 @@
 		   "\\`\\.")))
     (when (and recurse-p eshell-glob-show-progress)
       (message "Building file list...%d so far: %s"
-	       (length matches) path)
+	       (length eshell-glob-matches) path)
       (setq message-shown t))
     (if (equal path "./") (setq path ""))
     (while entries
@@ -332,7 +332,8 @@
 	  (if (cdr globs)
 	      (if isdir
 		  (setq dirs (cons (concat path name) dirs)))
-	    (setq matches (cons (concat path name) matches))))
+	    (setq eshell-glob-matches
+		  (cons (concat path name) eshell-glob-matches))))
       (if (and recurse-p isdir
 	       (or (> len 3)
 		   (not (or (and (= len 2) (equal name "./"))
@@ -358,5 +359,4 @@
 ;; generated-autoload-file: "esh-groups.el"
 ;; End:
 
-;; arch-tag: d0548f54-fb7c-4978-a88e-f7c26f7f68ca
 ;;; em-glob.el ends here
@@ -255,15 +255,15 @@
 (defvar message-shown)
 
-;; FIXME does this really need to abuse matches, message-shown?
+;; FIXME does this really need to abuse eshell-glob-matches, message-shown?
 (defun eshell-glob-entries (path globs &optional recurse-p)
   "Glob the entries in PATHS, possibly recursing if RECURSE-P is non-nil."